#[non_exhaustive]pub enum ProductData {
Heating {
id: String,
last_seen: Option<DateTime<Utc>>,
created_at: DateTime<Utc>,
properties: Properties,
state: States,
extra: HashMap<String, Value>,
},
HotWater {
id: String,
last_seen: Option<DateTime<Utc>>,
created_at: DateTime<Utc>,
properties: Properties,
state: States,
extra: HashMap<String, Value>,
},
Unknown,
}Expand description
Data about a Hive product.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Heating
A Hive Heating product.
Fields

last_seen: Option<DateTime<Utc>>The date and time when the Hive Heating product last communicated with the Hive servers.

properties: PropertiesThe properties of the Hive Heating product.
HotWater
A Hive Hot Water product.
Fields

last_seen: Option<DateTime<Utc>>The date and time when the Hive Hot Water product last communicated with the Hive servers.

properties: PropertiesThe properties of the Hive Hot Water product.
Unknown
A product which is yet to be mapped by the crate.